@@ -772,6 +772,11 @@ bool PowerMac7_3_CPUCoolingCtrlLoop::updateMetaState( void )
 	}
 }
 
+void PowerMac7_3_CPUCoolingCtrlLoop::adjustControls( void )
+{
+	// [4001211] Override to prevent calculateNewTarget() from being called from when the environment changes.
+}
+
 bool PowerMac7_3_CPUCoolingCtrlLoop::acquireSample( void )
 {
 	samplePoint * latest;
@@ -1114,7 +1119,7 @@ ControlValue PowerMac7_3_CPUCoolingCtrlLoop::calculateNewTarget( void ) const
 			result += (SInt32)accum;
 		}
 
-		newTarget = (UInt32)(result > 0) ? result : 0;
+		newTarget = ( ControlValue )( ( result > 0 ) ? result : 0 );
 
 		// apply the hard limits
 		if (newTarget < outputMin)
@@ -1291,11 +1296,14 @@ void PowerMac7_3_CPUCoolingCtrlLoop::deadlinePassed( void )
 		platformPlugin->sleepSystem();
 	}
 
-	// If we changed the environment, the platform plugin will invoke updateMetaState()
-	// and adjustControls().  If not, then we just need to call adjustControls()
-	if (!didSetEnv)
+	 // [4001211] Always calculate the PID function when the interval deadline expires.
+	if (ctrlloopState != kIOPCtrlLoopNotReady)
 	{
-		adjustControls();
+		// Apply the PID algorithm.
+		ControlValue newTarget = calculateNewTarget();
+
+		// set the target
+		sendNewTarget( newTarget );
 	}
 
 
